#
# spec file for package malaga-suomi
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name voikko-fi
%define _altname suomi-malaga
Name:           malaga-suomi
Version:        2.5
Release:        1.8
Summary:        Description of Finnish morphology written for libvoikko
License:        GPL-2.0-or-later
Group:          Productivity/Text/Spell
URL:            http://voikko.puimula.org/
Source0:        http://www.puimula.org/voikko-sources/%{_name}/%{_name}-%{version}.tar.gz
Source1:        http://www.puimula.org/voikko-sources/%{_name}/%{_name}-%{version}.tar.gz.asc
Source2:        %{_name}.keyring
# voikospell/libvoikko requires malaga-suomi for proper runtime. But to build malaga-suomi we don't need it yet
#!BuildIgnore:  malaga-suomi
BuildRequires:  foma
BuildRequires:  python3
BuildRequires:  voikkospell >= 4.0
Provides:       %{_name} = %{version}
Obsoletes:      %{_name} < %{version}
Provides:       %{_altname} = %{version}
Obsoletes:      %{_altname} < %{version}
BuildArch:      noarch

%description
Voikko-fi (previously known as suomi-malaga) is a description of Finnish
morphology written for libvoikko.

This package contains a compiled version of Voikko-fi using the new
unweighted VFST dictionary format. It is suitable for use in spell checking,
grammar checking and hyphenation system Voikko, provided by the libvoikko
library.

%prep
%setup -q -n %{_name}-%{version}

%build
CFLAGS="%{optflags}" \
CXXFLAGS="%{optflags}" \
make %{?_smp_mflags} vvfst EXTRA_LEX=vocabulary/erikoisalat/linux-distributions.lex SM_BUILDDATE="$(date --date="@${SOURCE_DATE_EPOCH:-$(date +%{s})}")"

%install
make vvfst-install DESTDIR=%{buildroot}%{_datadir}/voikko

%files
%license COPYING
%doc CONTRIBUTORS ChangeLog README.md
%dir %{_datadir}/voikko/
%{_datadir}/voikko/*

%changelog
* Wed Jun  8 2022 Timo Jyrinki <tjyrinki@suse.com>
- Update to new upstream version 2.5:
  * New words have been added and some bugs have been fixed.
- Update to new upstream version 2.45:
  * Automatic hkO derivation for adjectives has been implemented.
  * Extended special vocabulary for spoken Finnish.
  * New words have been added and various bugs have been fixed.
* Thu May  7 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildIgnore malaga-suomi: libvoikko1 does not require
  malaga-suomi as long as we just want to build stuff.
* Wed Sep 25 2019 Timo Jyrinki <tjyrinki@suse.com>
- Update to new upstream version 2.3:
  * Added special vocabulary for Statistics Finland.
  * Added support for packaging dictionaries as Emscripten preload files for web use.
  * Added Dockerfile to support setting up development environment.
  * New words have been added and various bugs have been fixed.
* Wed Feb 27 2019 Timo Jyrinki <tjyrinki@suse.com>
- Update to version 2.2
- Add GPG signature and keyring file
- Update description that it's no longer using malaga
* Thu Sep 27 2018 Tomáš Chvátal <tchvatal@suse.com>
- Use %%license to install the license
* Mon Jun 19 2017 bwiedemann@suse.com
- Override SM_BUILDDATE to make build fully reproducible
* Thu Jun  8 2017 dimstar@opensuse.org
- BuildIgnore malaga-suomi, otherwise this package can't be
  bootsrapped (nothing provides malaga-suomi needed by libvoikko1).
* Tue Apr 25 2017 tchvatal@suse.com
- Version update to 2.1
  * Switches from malaga to libvoikko completely
* Tue Nov 24 2015 p.drouand@gmail.com
- Update to version 1.19
  * Unmaintained ChangeLog
* Mon Feb  9 2015 tchvatal@suse.com
- Version bump to 1.18:
  * No changelog provided
* Thu Nov 13 2014 tchvatal@suse.com
- Version bump to lates releases
  * many new words and fixes
* Sun Jan 26 2014 tchvatal@suse.com
- Version bump to 1.15 moving to new upstream location:
  * tons of new words and bugs fixed.
* Fri Jan 11 2013 pmladek@suse.com
- Update to version 1.12 (bnc#795350):
  * uses voikko dictionary format 2 that has been needed since
    libvoikko, version 2.2
  * many new words and fixes
* Sun Jan 29 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
- Parallel building using %%_smp_mflags
* Mon Jun 22 2009 pmladek@suse.cz
- Update to version 1.3 (bnc#541664):
  * new words have been added, especially from medical field
  * many changes in Sukija
  * some bugs related to compound words have been fixed, leading to better
    spelling suggestions and more accurate hyphenation
  * significant improvements related to grammar checking
- Change location from %%%%{_datadir}/malaga to %%%%{_datadir}/malaga/1/mor-standard
  according to the last instructions, see
  http://voikko.sourceforge.net/source-linux.html
- Added symlinks for backward compatibility
* Fri Jul 25 2008 sbrabec@suse.cz
- New SuSE package based on spec file from Sami Vento (bnc#394355).
